@@ -8,6 +8,7 @@ class Arguments:
     url: str
     artists: List[str]
     album: str
+    split: bool
 
     def __init__(self, argv=None):
         parser = ArgumentParser(
@@ -21,11 +22,17 @@ class Arguments:
             type=lambda s: [name for name in s.split(",")],
         )
         parser.add_argument("--album", help="album name")
+        parser.add_argument(
+            "--split",
+            help="split song in multiple songs based on timestamps (youtube video description)",
+            action="store_true",
+        )
 
         args = parser.parse_args(argv)
         self.url = args.url
         self.artists = args.artists or []
         self.album = args.album
+        self.split = args.split
 
     def check(self):
         """
